<?php
/*
Copyright (C) 2008-2011 Stephane Graber <stgraber@ubuntu.com>

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

function qatracker_admin_series() {
    drupal_set_title(t("Series management"));
    $site = qatracker_get_current_site();

    # Standard header
    $items = qatracker_site_header($site);
    if (!$site) {
        return $items;
    }

    # Getting all the entries
    $query = db_select('qatracker_milestone_series');
    $query->fields('qatracker_milestone_series', array('id', 'title'));
    $query->orderBy('qatracker_milestone_series.title', 'ASC');
    $query->condition('qatracker_milestone_series.siteid', $site->id);
    $result = $query->execute();

    # And generating the table
    $rows = array();
    foreach ($result as $record) {
        $rows[] = array(
            $record->title,
            l(
                t("Edit"),
                "admin/config/services/qatracker/series/".$record->id."/edit",
                array(
                    'attributes' => array(
                        'class' => array('module-link', 'module-link-configure'),
                    ),
                )
            )
        );
    }

    $items[] = array(
        '#type' => 'link',
        '#prefix' => '<ul class="action-links"><li>',
        '#title' => t('Add a series'),
        '#suffix' => '</li></ul>',
        '#href' => 'admin/config/services/qatracker/series/add',
    );

    $items[] = array(
        '#theme' => 'table',
        '#header' => array(
            t('Title'),
            t('Actions')
        ),
        '#rows' => $rows,
    );

    return $items;
}

function qatracker_admin_series_edit($form, &$form_state) {
    drupal_set_title(t("Edit a series"));
    $args = arg();
    $index = count($args)-1;
    $action = $args[$index];

    if ($action == "edit" && count($args) == 7) {
        $query = db_select('qatracker_milestone_series');
        $query->condition('qatracker_milestone_series.id', $args[5]);
        $query->fields('qatracker_milestone_series', array('id', 'title'));
        $result = $query->execute();
        $entry = $result->fetch();
    }
    else {
        $entry = new stdClass();
        $entry->title = "";
    }

    $form = array();

    $form['qatracker_milestone_series'] = array(
        '#type' => 'fieldset',
        '#title' => t('Series'),
        '#collapsible' => TRUE,
        '#collapsed' => FALSE,
    );
    if ($action == "edit" && count($args) == 7) {
        $form['qatracker_milestone_series']['qatracker_milestone_series_id'] = array(
            '#type' => 'textfield',
            '#title' => t('ID'),
            '#default_value' => $entry->id,
            '#description' => t("ID of the series"),
            '#required' => TRUE,
            '#disabled' => TRUE,
        );
    }

    $form['qatracker_milestone_series']['qatracker_milestone_series_title'] = array(
        '#type' => 'textfield',
        '#title' => t('Title'),
        '#default_value' => $entry->title,
        '#description' => t("Title of the series"),
        '#required' => TRUE,
    );

    $form['actions'] = array('#type' => 'actions');
    if ($action == "edit" && count($args) == 7) {
        $form['actions']['submit'] = array(
            '#type' => 'submit',
            '#value' => t('Save'),
        );
    }
    else {
        $form['actions']['submit'] = array(
            '#type' => 'submit',
            '#value' => t('Create'),
        );
    }

    $form['actions']['cancel'] = array(
        '#markup' => l(t('Cancel'), 'admin/config/services/qatracker/series'),
    );

    return $form;
}

function qatracker_admin_series_edit_submit($form, &$form_state) {
    $args = arg();
    $index = count($args)-1;
    $action = $args[$index];

    if ($action == "edit" && count($args) == 7) {
        $query = db_update('qatracker_milestone_series');
        $query->condition('qatracker_milestone_series.id', $args[5]);
    }
    else {
        $query = db_insert('qatracker_milestone_series');
    }
    $query->fields(array(
        'siteid' => qatracker_get_current_site()->id,
        'title' => $form['qatracker_milestone_series']['qatracker_milestone_series_title']['#value'],
    ));
    $seriesid = $query->execute();

    if ($action == "edit") {
        watchdog("qatracker",
            t("Updated series with ID: @seriesid"),
            array('@seriesid' => $args[5])
        );
    }
    else {
        watchdog("qatracker",
            t("Added series with ID: @seriesid"),
            array('@seriesid' => $seriesid)
        );
    }

    $form_state['redirect'] = 'admin/config/services/qatracker/series';
    return $form;
}

?>
