<?php
/*
Copyright (C) 2008-2011 Stephane Graber <stgraber@ubuntu.com>

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

// Admin pages
require_once("admin/qatracker.admin.builds.php");
require_once("admin/qatracker.admin.families.php");
require_once("admin/qatracker.admin.milestones.php");
require_once("admin/qatracker.admin.products.php");
require_once("admin/qatracker.admin.products.downloads.php");
require_once("admin/qatracker.admin.products.testsuites.php");
require_once("admin/qatracker.admin.series.php");
require_once("admin/qatracker.admin.sites.php");
require_once("admin/qatracker.admin.summary.php");
require_once("admin/qatracker.admin.testcases.php");
require_once("admin/qatracker.admin.testsuites.php");

// User pages
require_once("user/qatracker.user.api.php");
require_once("user/qatracker.user.builds.php");
require_once("user/qatracker.user.milestones.php");
require_once("user/qatracker.user.products.buginstructions.php");
require_once("user/qatracker.user.products.downloads.php");
require_once("user/qatracker.user.results.php");
require_once("user/qatracker.user.testcases.php");

// Report pages
require_once("report/qatracker.report.bugs.php");
require_once("report/qatracker.report.defects.php");
require_once("report/qatracker.report.subscriptions.php");
require_once("report/qatracker.report.summary.php");
require_once("report/qatracker.report.testers.php");

function qatracker_menu() {
    $items = array();

    # User pages
    $items['qatracker'] = array(
        'title' => t("Testing tracker"),
        'description' => t("Testing tracker"),
        'page callback' => 'drupal_get_form',
        'page arguments' => array('qatracker_user_milestones'),
        'access arguments' => array("access content"),
        'type' => MENU_NORMAL_ITEM,
        'weight' => -10);

    $items['qatracker/milestones/%/history'] = array(
        'title' => t("Build history"),
        'page arguments' => array('qatracker_user_builds'),
        'access arguments' => array("access content"),
        'type' => MENU_VISIBLE_IN_BREADCRUMB,
    );

    $items['qatracker/milestones/%/builds'] = array(
        'title' => t("Builds"),
        'page arguments' => array('qatracker_user_builds'),
        'access arguments' => array("access content"),
        'type' => MENU_VISIBLE_IN_BREADCRUMB,
    );

    $items['qatracker/milestones/%/builds/%/buginstructions'] = array(
        'title' => t("Bug reporting instructions"),
        'page arguments' => array('qatracker_user_products_buginstructions'),
        'access arguments' => array("access content"),
        'type' => MENU_VISIBLE_IN_BREADCRUMB,
    );

    $items['qatracker/milestones/%/builds/%/downloads'] = array(
        'title' => t("Downloads"),
        'page arguments' => array('qatracker_user_products_downloads'),
        'access arguments' => array("access content"),
        'type' => MENU_VISIBLE_IN_BREADCRUMB,
    );

    $items['qatracker/milestones/%/builds/%/testcases'] = array(
        'title' => t("Testcases"),
        'page arguments' => array('qatracker_user_testcases'),
        'access arguments' => array("access content"),
        'type' => MENU_VISIBLE_IN_BREADCRUMB,
    );

    $items['qatracker/milestones/%/builds/%/testcases/%/results'] = array(
        'title' => t("Results"),
        'page arguments' => array('qatracker_user_results'),
        'access arguments' => array("access content"),
        'type' => MENU_VISIBLE_IN_BREADCRUMB,
    );

    # NOTE: Because of MENU_MAX_PARTS being 9, we can't bind /edit although
    # we use it in the URLs for consistency.
    # This will only be a problem when we need something else than /edit
    $items['qatracker/milestones/%/builds/%/testcases/%/results/%'] = array(
        'title' => t("Edit result"),
        'page arguments' => array('qatracker_user_results_edit', 'edit'),
        'access callback' => 'qatracker_acl',
        'access arguments' => array('administer site configuration', array('user')),
        'type' => MENU_VISIBLE_IN_BREADCRUMB,
    );

    $items['qatracker/subscription'] = array(
        'title' => t("Subscriptions"),
        'description' => t("Subscriptions to testcases"),
        'page callback' => "qatracker_main",
        'access callback' => 'qatracker_acl',
        'access arguments' => array('administer site configuration', array('user')),
        'type' => MENU_NORMAL_ITEM,
        'weight' => -9);

    $items['qatracker/api'] = array(
        'title' => t("API"),
        'description' => t("API"),
        'page callback' => "drupal_get_form",
        'page arguments' => array('qatracker_user_api'),
        'access callback' => 'qatracker_acl',
        'access arguments' => array('administer site configuration', array('user')),
        'type' => MENU_NORMAL_ITEM,
        'weight' => -8);

    $items['qatracker/reportbug'] = array(
        'title' => t("Report a bug"),
        'description' => t("Report a bug"),
        'page callback' => "drupal_goto",
        'page arguments' => array('https://bugs.launchpad.net/ubuntu-qa-website/+filebug?no-redirect&field.tags=qa-tracker'),
        'access arguments' => array('access content'),
        'type' => MENU_NORMAL_ITEM,
        'weight' => -7);

    $items['qatracker/testcases/%/info'] = array(
        'title' => t("Testcase details"),
        'page arguments' => array('qatracker_user_testcases_info'),
        'access arguments' => array("access content"),
        'type' => MENU_VISIBLE_IN_BREADCRUMB,
    );

    $items['qatracker/testcases/%/revisions/%/info'] = array(
        'title' => t("Testcase revision"),
        'page arguments' => array('qatracker_user_testcases_info'),
        'access arguments' => array("access content"),
        'type' => MENU_VISIBLE_IN_BREADCRUMB,
    );

    # Reports
    $items['qatracker/reports'] = array(
        'title' => t("Reports"),
        'description' => t("Reports"),
        'page callback' => "qatracker_report",
        'access arguments' => array("access content"),
        'type' => MENU_NORMAL_ITEM,
        'weight' => -10);

    $items['qatracker/reports/defects'] = array(
        'title' => t("Defects Summary"),
        'description' => t("Defects Summary"),
        'page callback' => "qatracker_report_defects",
        'access arguments' => array("access content"),
        'type' => MENU_NORMAL_ITEM,
        'weight' => -10);

    $items['qatracker/reports/defects/opened'] = array(
        'title' => t("Open Defects"),
        'description' => t("Testing report"),
        'page callback' => "qatracker_report_defects",
        'access arguments' => array("access content"),
        'type' => MENU_NORMAL_ITEM,
        'weight' => -10);

    $items['qatracker/reports/defects/closed'] = array(
        'title' => t("Closed Defects"),
        'description' => t("Testing report"),
        'page callback' => "qatracker_report_defects",
        'access arguments' => array("access content"),
        'type' => MENU_NORMAL_ITEM,
        'weight' => -9);

    $items['qatracker/reports/subscriptions'] = array(
        'title' => t("Testcase subscriptions"),
        'description' => t("Testcase subscriptions"),
        'page callback' => "qatracker_report_subscriptions",
        'access arguments' => array("access content"),
        'type' => MENU_NORMAL_ITEM,
        'weight' => -9);

    $items['qatracker/reports/testers'] = array(
        'title' => t("Top testers (current milestones)"),
        'description' => t("Top testers (current milestones)"),
        'page callback' => "qatracker_report_testers",
        'access arguments' => array("access content"),
        'type' => MENU_NORMAL_ITEM,
        'weight' => -8);

    $items['qatracker/reports/testers/top20'] = array(
        'title' => t("Top 20 (of all time)"),
        'description' => t("Top 20 (of all time)"),
        'page callback' => "qatracker_report_testers",
        'access arguments' => array("access content"),
        'type' => MENU_NORMAL_ITEM,
        'weight' => -8);

    $items['qatracker/reports/bugs'] = array(
        'title' => t("Search by bug number"),
        'description' => t("Search for results for a given bugnumber"),
        'page callback' => "drupal_get_form",
        'page arguments' => array("qatracker_report_bugs"),
        'access arguments' => array("access content"),
        'type' => MENU_NORMAL_ITEM,
        'weight' => -7);

    $items['qatracker/reports/bugs/%'] = array(
        'title' => t("List of results for bugnumber"),
        'description' => t("List of results for a given bugnumber"),
        'page callback' => "qatracker_report_bugs_bugnumber",
        'access arguments' => array("access content"),
        'type' => MENU_NORMAL_ITEM,
        'weight' => -8);

    # Link to the admin interface from the user interface
    $items['qatracker/admin'] = array(
        'title' => t('Administration'),
        'description' => t('Settings for the testing tracker module.'),
        'type' => MENU_NORMAL_ITEM,
        'page callback' => 'drupal_goto',
        'page arguments' => array('admin/config/services/qatracker'),
        'access callback' => "qatracker_acl",
        'access arguments' => array('administer site configuration', array('admin', 'product', 'testcase')),
    );

    # Admin pages
    $items['admin/config/services/qatracker'] = array(
        'title' => t('Testing tracker configuration'),
        'description' => t('Settings for the testing tracker module.'),
        'type' => MENU_NORMAL_ITEM,
        'page callback' => 'drupal_get_form',
        'page arguments' => array('qatracker_admin'),
        'access callback' => "qatracker_acl",
        'access arguments' => array('administer site configuration', array('admin', 'product', 'testcase')),
    );

    $items['admin/config/services/qatracker/summary'] = array(
        'title' => t('Summary'),
        'type' => MENU_DEFAULT_LOCAL_TASK,
        'weight' => 0,
    );

    $items['admin/config/services/qatracker/sites'] = array(
        'title' => t('Sites'),
        'description' => t('Create and modify testing tracker instances'),
        'page arguments' => array('qatracker_admin_sites'),
        'access callback' => "user_access",
        'access arguments' => array('administer site configuration'),
        'type' => MENU_LOCAL_TASK,
        'weight' => 1,
    );

    $items['admin/config/services/qatracker/sites/add'] = array(
        'title' => t("Add a site"),
        'page arguments' => array('qatracker_admin_sites_edit', "add"),
        'access callback' => "user_access",
        'access arguments' => array('administer site configuration'),
        'type' => MENU_VISIBLE_IN_BREADCRUMB,
    );

    $items['admin/config/services/qatracker/sites/%/edit'] = array(
        'title' => t("Edit a site"),
        'page arguments' => array('qatracker_admin_sites_edit', "edit"),
        'access callback' => "user_access",
        'access arguments' => array('administer site configuration'),
        'type' => MENU_VISIBLE_IN_BREADCRUMB,
    );

    $items['admin/config/services/qatracker/families'] = array(
        'title' => t('Product families'),
        'description' => t('Create and modify product families'),
        'page arguments' => array('qatracker_admin_families'),
        'access callback' => "qatracker_acl",
        'access arguments' => array('administer site configuration', array('admin')),
        'type' => MENU_LOCAL_TASK,
        'weight' => 2,
    );

    $items['admin/config/services/qatracker/families/add'] = array(
        'title' => t("Add a product family"),
        'page arguments' => array('qatracker_admin_families_edit', "add"),
        'access callback' => "qatracker_acl",
        'access arguments' => array('administer site configuration', array('admin')),
        'type' => MENU_VISIBLE_IN_BREADCRUMB,
    );

    $items['admin/config/services/qatracker/families/%/edit'] = array(
        'title' => t("Edit a product family"),
        'page arguments' => array('qatracker_admin_families_edit', "edit"),
        'access callback' => "qatracker_acl",
        'access arguments' => array('administer site configuration', array('admin')),
        'type' => MENU_VISIBLE_IN_BREADCRUMB,
    );

    $items['admin/config/services/qatracker/products'] = array(
        'title' => t('Products'),
        'description' => t('Create and modify products'),
        'page arguments' => array('qatracker_admin_products'),
        'access callback' => "qatracker_acl",
        'access arguments' => array('administer site configuration', array('admin', 'product')),
        'type' => MENU_LOCAL_TASK,
        'weight' => 3,
    );

    $items['admin/config/services/qatracker/products/add'] = array(
        'title' => t("Add a product"),
        'page arguments' => array('qatracker_admin_products_edit', "add"),
        'access callback' => "qatracker_acl",
        'access arguments' => array('administer site configuration', array('admin')),
        'type' => MENU_VISIBLE_IN_BREADCRUMB,
    );

    $items['admin/config/services/qatracker/products/%/edit'] = array(
        'title' => t("Edit a product"),
        'page arguments' => array('qatracker_admin_products_edit', "edit"),
        'access callback' => "qatracker_acl",
        'access arguments' => array('administer site configuration', array('admin', 'product')),
        'type' => MENU_VISIBLE_IN_BREADCRUMB,
    );

    $items['admin/config/services/qatracker/products/%/downloads'] = array(
        'title' => t("Downloads"),
        'page arguments' => array('qatracker_admin_downloads'),
        'access callback' => "qatracker_acl",
        'access arguments' => array('administer site configuration', array('admin', 'product')),
        'type' => MENU_VISIBLE_IN_BREADCRUMB,
    );

    $items['admin/config/services/qatracker/products/%/downloads/add'] = array(
        'title' => t("Add a link"),
        'page arguments' => array('qatracker_admin_downloads_edit', "add"),
        'access callback' => "qatracker_acl",
        'access arguments' => array('administer site configuration', array('admin', 'product')),
        'type' => MENU_VISIBLE_IN_BREADCRUMB,
    );

    $items['admin/config/services/qatracker/products/%/downloads/%/edit'] = array(
        'title' => t("Edit a link"),
        'page arguments' => array('qatracker_admin_downloads_edit', "edit"),
        'access callback' => "qatracker_acl",
        'access arguments' => array('administer site configuration', array('admin', 'product')),
        'type' => MENU_VISIBLE_IN_BREADCRUMB,
    );

    $items['admin/config/services/qatracker/products/%/testsuites'] = array(
        'title' => t("Testsuites"),
        'page arguments' => array('qatracker_admin_product_testsuites'),
        'access callback' => "qatracker_acl",
        'access arguments' => array('administer site configuration', array('admin', 'product')),
        'type' => MENU_VISIBLE_IN_BREADCRUMB,
    );

    $items['admin/config/services/qatracker/testcases'] = array(
        'title' => t("Testcases"),
        'description' => t('Create and modify testcases'),
        'page arguments' => array('qatracker_admin_testcases'),
        'access callback' => "qatracker_acl",
        'access arguments' => array('administer site configuration', array('admin', 'testcase')),
        'type' => MENU_LOCAL_TASK,
        'weight' => 4,
    );

    $items['admin/config/services/qatracker/testcases/add'] = array(
        'title' => t("Add a testcase"),
        'page arguments' => array('qatracker_admin_testcases_edit', "add"),
        'access callback' => "qatracker_acl",
        'access arguments' => array('administer site configuration', array('admin', 'testcase')),
        'type' => MENU_VISIBLE_IN_BREADCRUMB,
    );

    $items['admin/config/services/qatracker/testcases/%/edit'] = array(
        'title' => t("Edit a testcase"),
        'page arguments' => array('qatracker_admin_testcases_edit', "edit"),
        'access callback' => "qatracker_acl",
        'access arguments' => array('administer site configuration', array('admin', 'testcase')),
        'type' => MENU_VISIBLE_IN_BREADCRUMB,
    );

    $items['admin/config/services/qatracker/testsuites'] = array(
        'title' => t("Testsuites"),
        'description' => t('Create and modify testsuitess'),
        'page arguments' => array('qatracker_admin_testsuites'),
        'access callback' => "qatracker_acl",
        'access arguments' => array('administer site configuration', array('admin', 'testcase')),
        'type' => MENU_LOCAL_TASK,
        'weight' => 5,
    );

    $items['admin/config/services/qatracker/testsuites/add'] = array(
        'title' => t("Add a testsuite"),
        'page arguments' => array('qatracker_admin_testsuites_edit', "add"),
        'access callback' => "qatracker_acl",
        'access arguments' => array('administer site configuration', array('admin', 'testcase')),
        'type' => MENU_VISIBLE_IN_BREADCRUMB,
    );

    $items['admin/config/services/qatracker/testsuites/%/edit'] = array(
        'title' => t("Edit a testsuite"),
        'page arguments' => array('qatracker_admin_testsuites_edit', "edit"),
        'access callback' => "qatracker_acl",
        'access arguments' => array('administer site configuration', array('admin', 'testcase')),
        'type' => MENU_VISIBLE_IN_BREADCRUMB,
    );

    $items['admin/config/services/qatracker/series'] = array(
        'title' => t('Series'),
        'description' => t('Create and modify series'),
        'page arguments' => array('qatracker_admin_series'),
        'access callback' => "qatracker_acl",
        'access arguments' => array('administer site configuration', array('admin')),
        'type' => MENU_LOCAL_TASK,
        'weight' => 6,
    );

    $items['admin/config/services/qatracker/series/add'] = array(
        'title' => t("Add a series"),
        'page arguments' => array('qatracker_admin_series_edit', "add"),
        'access callback' => "qatracker_acl",
        'access arguments' => array('administer site configuration', array('admin')),
        'type' => MENU_VISIBLE_IN_BREADCRUMB,
    );

    $items['admin/config/services/qatracker/series/%/edit'] = array(
        'title' => t("Edit a series"),
        'page arguments' => array('qatracker_admin_series_edit', "edit"),
        'access callback' => "qatracker_acl",
        'access arguments' => array('administer site configuration', array('admin')),
        'type' => MENU_VISIBLE_IN_BREADCRUMB,
    );

    $items['admin/config/services/qatracker/milestones'] = array(
        'title' => t('Milestones'),
        'description' => t('Create and modify milestones'),
        'page arguments' => array('qatracker_admin_milestones'),
        'access callback' => "qatracker_acl",
        'access arguments' => array('administer site configuration', array('admin')),
        'type' => MENU_LOCAL_TASK,
        'weight' => 7,
    );

    $items['admin/config/services/qatracker/milestones/add'] = array(
        'title' => t("Add a milestone"),
        'page arguments' => array('qatracker_admin_milestones_edit', "add"),
        'access callback' => "qatracker_acl",
        'access arguments' => array('administer site configuration', array('admin')),
        'type' => MENU_VISIBLE_IN_BREADCRUMB,
    );

    $items['admin/config/services/qatracker/milestones/%/edit'] = array(
        'title' => t("Edit a milestone"),
        'page arguments' => array('qatracker_admin_milestones_edit', "edit"),
        'access callback' => "qatracker_acl",
        'access arguments' => array('administer site configuration', array('admin')),
        'type' => MENU_VISIBLE_IN_BREADCRUMB,
    );

    $items['admin/config/services/qatracker/builds'] = array(
        'title' => t('Builds'),
        'description' => t('Create and modify builds'),
        'page arguments' => array('qatracker_admin_builds'),
        'access callback' => "qatracker_acl",
        'access arguments' => array('administer site configuration', array('admin', 'product')),
        'type' => MENU_LOCAL_TASK,
        'weight' => 8,
    );

    $items['admin/config/services/qatracker/builds/%/edit'] = array(
        'title' => t("Edit a build"),
        'page arguments' => array('qatracker_admin_builds_edit', "edit"),
        'access callback' => "qatracker_acl",
        'access arguments' => array('administer site configuration', array('admin', 'product')),
        'type' => MENU_VISIBLE_IN_BREADCRUMB,
    );

    return $items;
}

function qatracker_main() {
    $items = array();

    $items[] = array(
        '#type' => 'markup',
        '#prefix' => '<p>',
        '#markup' => t("Still a work in progress, this page should hopefully be done soon :)"),
        '#suffix' => '</p>',
    );

    return $items;
}

function qatracker_mail($key, &$message, $params) {
    $site = qatracker_get_current_site();

    $data['user'] = $params['account'];
    $options['language'] = $message['language'];
    user_mail_tokens($variables, $data, $options);

    $langcode = $message['language']->language;

    switch($key) {
        case 'builds_new':
            $message['subject'] = t(
                '!site: New build notification',
                array('!site' => $site->title),
                array('langcode' => $langcode)
            );

            $note = $params['build']->note;
            if (!$params['build']->note) {
                $note = t("None");
            }

            $testcases = "";
            foreach ($params['testcases'] as $testcase) {
                $testcases.= "\n - ".$testcase;
            }

            $message['body'][] = t(
                "A new build of !product is ready for testing!
Version: !version
Link: !build_link

Testcases:!testcase_list

Build notes:
!build_note

-- 
You are receiving this e-mail because you subscribed to this product
on the !site testing tracker.

You can change your subscription options at: !subscription_link",
                array(
                    '!product' => $params['product']->title,
                    '!version' => $params['build']->version,
                    '!build_link' => url("qatracker/milestones/".$params['milestone']->id."/builds/".$params['build']->id."/testcases", array("absolute" => TRUE)),
                    '!testcase_list' => $testcases,
                    '!build_note' => $note,
                    '!site' => $site->title,
                    '!subscription_link' => url("qatracker/subscription", array("absolute" => TRUE)),
                ),
                array('langcode' => $langcode)
            );
        break;

        case 'builds_bad':
            $message['subject'] = t('Notification from !site', $variables, array('langcode' => $langcode));
            $message['body'][] = t("Dear !username\n\nThere is new content available on the site.", $variables, array('langcode' => $langcode));
        break;

        case 'builds_remove':
            $message['subject'] = t('Notification from !site', $variables, array('langcode' => $langcode));
            $message['body'][] = t("Dear !username\n\nThere is new content available on the site.", $variables, array('langcode' => $langcode));
        break;
    }
}

?>
