<?php
/*
Copyright (C) 2008-2011 Stephane Graber <stgraber@ubuntu.com>

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

function qatracker_report_subscriptions() {
    global $qatracker_testsuite_testcase_status;
    $site = qatracker_get_current_site();

    # Standard header
    $items = qatracker_site_header($site);
    if (!$site) {
        return $items;
    }

    # Getting all the entries
    $query = db_select('qatracker_testcase');
    $query->fields('qatracker_testcase', array('id', 'title', 'link'));
    $query->fields('qatracker_testsuite_testcase', array('status'));
    $query->addField('qatracker_product', 'title', 'product');
    $query->addField('qatracker_product', 'id', 'productid');
    $query->addField('qatracker_product', 'familyid', 'familyid');
    $query->leftjoin('qatracker_testsuite_testcase', 'qatracker_testsuite_testcase', 'qatracker_testsuite_testcase.testcaseid = qatracker_testcase.id');
    $query->leftjoin('qatracker_testsuite_product', 'qatracker_testsuite_product', 'qatracker_testsuite_product.testsuiteid = qatracker_testsuite_testcase.testsuiteid');
    $query->leftjoin('qatracker_product', 'qatracker_product', 'qatracker_product.id = qatracker_testsuite_product.productid');
    $query->orderBy('qatracker_product.title', 'ASC');
    $query->orderBy('qatracker_testsuite_testcase.status', 'ASC');
    $query->orderBy('qatracker_testsuite_testcase.weight', 'ASC');
    $query->condition('qatracker_product.siteid', $site->id);
    $query->condition('qatracker_product.status', 0);
    $query->condition('qatracker_testsuite_testcase.status', 1, '<>');
    $query->distinct();
    $result = $query->execute();

    # And generating the table
    $rows = array();
    $family = -1;

    function new_table($rows) {
        return array(
            '#theme' => 'table',
            '#header' => array(
                array('data' => t('Product'), 'style' => 'width:30em'),
                array('data' => t('Testcase')),
                array('data' => t('Priority'), 'style' => 'width:8em'),
                array('data' => t('Subscribers'), 'style' => 'width:8em'),
            ),
            '#rows' => $rows,
        );
    }

    foreach ($result as $record) {
        if ($family != -1 && $family != $record->familyid) {
            $items[] = new_table($rows);
            $rows = array();
        }

        $query = db_select('qatracker_user_subscription');
        $query->leftjoin('users', 'users', 'users.uid = qatracker_user_subscription.userid');
        $query->fields('users', array('name'));
        $query->condition('qatracker_user_subscription.testcaseid', $record->id);
        $query->condition('qatracker_user_subscription.productid', $record->productid);
        $users_result = $query->execute();

        $count = $users_result->rowCount();

        if ($count == 0) {
            $count = t("None");
        }
        else {
            $count = qatracker_tooltip("left", "#", $count, implode("<br />", $users_result->fetchCol()));
        }

        $rows[$record->id] = array(
            $record->product,
            $record->title,
            $qatracker_testsuite_testcase_status[$record->status],
            $count,
        );
        $family = $record->familyid;
    }
    $items[] = new_table($rows);

    return $items;
}
?>
