<?php
/*
Copyright (C) 2008-2011 Stephane Graber <stgraber@ubuntu.com>

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

function qatracker_user_milestones() {
    global $qatracker_milestone_status;

    # FIXME: Turn off caching for now as it's a fairly trivial page to render
    drupal_page_is_cacheable(FALSE);

    $site = qatracker_get_current_site();
    $items = qatracker_site_header($site);

    # Return on invalid website
    if (!$site) {
        return $items;
    }

    # Get the list of active milestones
    $query = db_select('qatracker_milestone');
    $query->fields('qatracker_milestone', array('id', 'title', 'status'));
    $query->condition('qatracker_milestone.siteid', $site->id);

    # Support basic filtering by appending the status to the URL
    if (arg(2)) {
        $flipped_status = array_flip($qatracker_milestone_status);
        if (array_key_exists(arg(2), $flipped_status)) {
            $query->condition('qatracker_milestone.status', $flipped_status[arg(2)]);
        }
    }
    else {
        $query->condition('qatracker_milestone.status', array(0, 1), "IN");
    }

    $query->orderBy('qatracker_milestone.status', 'ASC');
    $query->orderBy('qatracker_milestone.id', 'DESC');
    $result = $query->execute();
    $rowcount = $result->rowCount();

    if ($rowcount == 0) {
        $items[] = array(
            '#type' => 'markup',
            '#prefix' => '<p>',
            '#markup' => t("There currently isn't any active milestone."),
            '#suffix' => '</p>',
        );
    }
    elseif ($rowcount == 1 && !arg(2)) {
        $milestone = $result->fetch();

        # Redirect to the current milestone
        return drupal_goto("qatracker/milestones/".$milestone->id."/builds");
    }
    else {
        $items[] = array(
            '#type' => 'markup',
            '#prefix' => '<p>',
            '#markup' => t("Please choose a milestone in the list below."),
            '#suffix' => '</p>',
        );

        $rows = array();
        foreach($result as $milestone) {
            $rows[] = array(
                l($milestone->title, "qatracker/milestones/".$milestone->id."/builds"),
                $qatracker_milestone_status[$milestone->status],
            );
        }

        $items[] = array(
            '#theme' => 'table',
            '#header' => array(
                array('data' => t('Milestone')),
                array('data' => t('Status'), 'style' => 'width:0'),
            ),
            '#rows' => $rows,
        );
    }

    # Generate a list of filters based on valid milestone statuses
    $cols = array(
        t("Filter the milestone list"),
        l(t("default"), "qatracker/milestones"),
        l(t("all"), "qatracker/milestones/all")
    );

    foreach ($qatracker_milestone_status as $status) {
        $cols[] = l(t($status), "qatracker/milestones/".$status);
    }

    $items[] = array(
        '#theme' => 'table',
        '#rows' => array($cols),
    );


    return $items;
}

?>
